@@ -7,7 +7,7 @@ use Scalar::Util 'looks_like_number';
 use List::Util   qw< min max uniq>;
 use version;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 # Default naming scheme for refactoring...
 my $DEFAULT_SUB_NAME          = '__REFACTORED_SUB__';
@@ -1762,8 +1762,9 @@ sub classify_all_vars_in {
 
                         # Otherwise record its usage in the appropriate slot (if any)...
                         else {
+                            my $varlen = length($var);
                             my $sigil  = substr($var, 0, 1, q{});
-                            my $twigil = length($var) > 1 && substr($var, 0, 1) eq '#'
+                            my $twigil = $varlen > 1 && substr($var, 0, 1) eq '#'
                                             ? substr($var, 0, 1, q{})
                                             : q{};
                             (my $cleanvar = $var) =~ s/[^\w:'^]+//g;
@@ -1773,7 +1774,7 @@ sub classify_all_vars_in {
                                    :                      $sigil) . $var;
                             $Code::ART::varuse
                                 {$Code::ART::varscope[-1]{ids}{$var} // $var}
-                                    {$varid} = 1;
+                                    {$varid} = $varlen;
                         }
                     })
                 )
@@ -1891,9 +1892,18 @@ sub classify_all_vars_in {
     }
 
     # Install standard descriptions and apply analyses...
-    for my $var (values %Code::ART::varinfo) {
+    my %var_at;
+    for my $varid (keys %Code::ART::varinfo) {
+        my $var = $Code::ART::varinfo{$varid};
         my $var_name = $var->{raw_name};
 
+        # Invert usages...
+        for my $startpos (keys %{$var->{used_at}}) {
+            for my $offset (0 .. $var->{used_at}{$startpos}) {
+                $var_at{ $startpos + $offset } = $varid;
+            }
+        }
+
         # Check whether variable is a built-in...
         $var->{is_builtin} = 0;
         if (my $std_desc = $STD_VAR_DESC{$var->{decl_name}}) {
@@ -1930,7 +1940,11 @@ sub classify_all_vars_in {
     }
 
     # Return all the information acquired...
-    return { vars => \%Code::ART::varinfo, use_version => $Code::ART::use_version }
+    return {
+        vars        => \%Code::ART::varinfo,
+        var_at      => \%var_at,
+        use_version => $Code::ART::use_version,
+    }
 }
 
 
@@ -1944,7 +1958,7 @@ Code::ART - Analyze/Rename/Track Perl source code
 
 =head1 VERSION
 
-This document describes Code::ART version 0.000002
+This document describes Code::ART version 0.000003
 
 
 =head1 SYNOPSIS
@@ -2591,7 +2605,7 @@ magical A.I. superfriends. Trust...but verify.
 No bugs have been reported.
 
 Please report any bugs or feature requests to
-C<bug-code-art.cpan.org>, or through the web interface at
+C<bug-code-art@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
 
